[gnome-video-arcade] Add "http" as an option for GVA_DEBUG.
- From: Matthew Barnes <mbarnes src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnome-video-arcade] Add "http" as an option for GVA_DEBUG.
- Date: Thu, 23 Jun 2011 00:10:11 +0000 (UTC)
commit 8a8f743783b06f1f195a6cb7343724333b1263b5
Author: Matthew Barnes <mbarnes redhat com>
Date: Fri Jun 3 21:28:58 2011 -0500
Add "http" as an option for GVA_DEBUG.
This option will integrate with SoupLogger.
docs/reference/tmpl/gva-util.sgml | 1 +
src/gva-util.c | 3 ++-
src/gva-util.h | 8 ++++++--
3 files changed, 9 insertions(+), 3 deletions(-)
---
diff --git a/docs/reference/tmpl/gva-util.sgml b/docs/reference/tmpl/gva-util.sgml
index 597c03b..8bf96c9 100644
--- a/docs/reference/tmpl/gva-util.sgml
+++ b/docs/reference/tmpl/gva-util.sgml
@@ -58,6 +58,7 @@
@GVA_DEBUG_IO:
@GVA_DEBUG_INP:
@GVA_DEBUG_GST:
+ GVA_DEBUG_HTTP:
<!-- ##### FUNCTION gva_get_last_version ##### -->
<para>
diff --git a/src/gva-util.c b/src/gva-util.c
index 3152bbe..7c62527 100644
--- a/src/gva-util.c
+++ b/src/gva-util.c
@@ -172,7 +172,8 @@ gva_get_debug_flags (void)
{ "sql", GVA_DEBUG_SQL },
{ "io", GVA_DEBUG_IO },
{ "inp", GVA_DEBUG_INP },
- { "gst", GVA_DEBUG_GST }
+ { "gst", GVA_DEBUG_GST },
+ { "http", GVA_DEBUG_HTTP }
};
const gchar *env = g_getenv ("GVA_DEBUG");
diff --git a/src/gva-util.h b/src/gva-util.h
index ddc7e2b..3285d90 100644
--- a/src/gva-util.h
+++ b/src/gva-util.h
@@ -45,10 +45,13 @@ G_BEGIN_DECLS
* Print information about input files.
* @GVA_DEBUG_GST:
* Print GStreamer activity.
+ * @GVA_DEBUG_HTTP:
+ * Print HTTP communication.
*
* These flags indicate which types of debugging messages will be triggered
* at runtime. Debugging messages can be triggered by setting the GVA_DEBUG
* environment variable to a colon-separated list of "mame", "sql" and "io".
**/
typedef enum
{
@@ -57,7 +60,8 @@ typedef enum
GVA_DEBUG_SQL = 1 << (G_LOG_LEVEL_USER_SHIFT + 1),
GVA_DEBUG_IO = 1 << (G_LOG_LEVEL_USER_SHIFT + 2),
GVA_DEBUG_INP = 1 << (G_LOG_LEVEL_USER_SHIFT + 3),
- GVA_DEBUG_GST = 1 << (G_LOG_LEVEL_USER_SHIFT + 4)
+ GVA_DEBUG_GST = 1 << (G_LOG_LEVEL_USER_SHIFT + 4),
+ GVA_DEBUG_HTTP = 1 << (G_LOG_LEVEL_USER_SHIFT + 5)
} GvaDebugFlags;
gchar * gva_choose_inpname (const gchar *game);
[
@@ -45,10 +45,13 @@ G_BEGIN_DECLS
* These flags indicate which types of debugging messages will be triggered
* at runtime. Debugging messages can be triggered by setting the GVA_DEBUG
- * environment variable to a colon-separated list of "mame", "sql" and "io".
+ * environment variable to a colon-separated list of "mame", "sql", "io",
+ * "inp", "gst" and "http".
**/
typedef enum
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]